@@ -40,11 +40,12 @@ fn main() -> CliResult {
 
     let mut ws = subcommand_args.workspace(&config)?;
 
-    let (build_targets, _, _, static_libs, compile_opts) =
+    let (build_targets, _, capi_config, static_libs, compile_opts) =
         cbuild(&mut ws, &config, &subcommand_args, "dev")?;
 
     ctest(
         &ws,
+        &capi_config,
         &config,
         subcommand_args,
         build_targets,
